Attribute VB_Name = "DSS_fellespublisering"
Sub DSS_1_Rydd_manus_og_fiks_tegnsetting()
'
' Makro som fikser vanlige tegnsettingsproblemer i manus. Ment for dokumenter tilknyttet fellespubliserings-mal som skal layoutes i InDesign.
'
' Makro opprettet 18.12.2020 av Jonas M. Rogne, Departementenes sikkerhets- og serviceorganisasjon.
' Siste endringer:
' 29.11.2024 Sletter n kun bokmerker hvis bruker sier ja til  fjerne kryssreferanser.
' 22.04.2025 kt terskelverdi for stilopprydding, fjernet mulig stopp i stilopprydding, legger "fotnotetekst"-stil p fotnoter, fjerner "l-endring" fra tekst som ikke er kursiv. Legger "l-endring" p kursiv tekst i l-ledd og l-punktum.

Application.ScreenUpdating = False                      'Ikke oppdater skjermbilde mens makro kjrer for  bedre ytelsen
Application.ActiveWindow.View = wdNormalView            'Sett til kladdevisning for  bedre ytelsen (?)
Application.DisplayStatusBar = True                     'Setter oppdatering av statusbar til manuell for  bedre ytelsen (?)
Application.Statusbar = "Starter opprydding..."         'Sett melding i statusfelt s brukeren vet hva som skjer (denne oppfrselen er ikke lenger offisielt stttet i Word, men funker delvis greit)

strListSep = Application.International(wdListSeparator) 'Lagre listeseparator som variabel. Dette for  sttte andre regionsinnstillinger enn norsk. M da bruke denne variabelen i stedet for semikolon i skestrenger.

ActiveDocument.AcceptAllRevisions                       'Godta alle endringer
ActiveDocument.TrackRevisions = False                   'Stopp sporing ("Sport Endringer" vil ellers fre til feil ved kjring av makro)

ActiveDocument.StoryRanges(wdMainTextStory).Select      'Marker dokumentteksten (s vi ikke str inne i f.eks. fotnoter eller topptekst)

' ======= KONTROLLERE og BOKMERKER =======
' Denne koden fjerner alle kontrollere (content controls) og bokmerker.

  Dim oRng As Range
  Dim cc   As ContentControl
  Dim LC   As Integer
  Dim LRCC As Integer
  Dim LTCC As Integer
  Dim LE   As Boolean

    'Remove all content controls
    Set oRng = ActiveDocument.Content
    LTCC = LTCC + oRng.ContentControls.Count
    For LC = oRng.ContentControls.Count To 1 Step -1
    
    Set cc = oRng.ContentControls(LC)
    If cc.LockContentControl = True Then
       cc.LockContentControl = False
    End If
    cc.Delete
    If Not LE Then
        LRCC = LRCC + 1
        End If
        LE = False
    Next


' ======= FJERN KRYSSREFERANSER? =======

If ActiveDocument.Fields.Count >= 1 Then

    Application.Statusbar = "Konvertering av felter..."
    fjernxref = MsgBox("Konverter bibliografi- og kryssreferanser til statisk tekst, og slett bokmerker?", vbYesNo + vbInfo + vbDefaultButton1, "Fjern kryssreferanser?") '
    
    If fjernxref = vbYes Then '--- Ja, konverter kryssreferanser
        ' Selve Bibliografi-blokken blir stende (m konverteres manuelt), men alle referansene til den i teksten blir statisk tekst.
        ' For alle story-ranges i dokumentet (alts inkluderer det bde innhold og fotnoter)
        For Each sr In ActiveDocument.StoryRanges
            For Each fld In sr.Fields 'For hvert felt
                If fld.Type = wdFieldCitation Then       ' Hvis det er sitering (tilhrende bibliografi)
                    fld.Select
                    WordBasic.BibliographyCitationToText ' Konverter til statisk tekst
                ElseIf fld.Type = wdFieldRef Then        ' Hvis kryssreferanse
                    fld.Unlink                           ' Unlinking feltet (gjr det til statisk tekst)
                End If
            Next
        Next
        'Fjern alle bokmerker, inkludert skjulte (dette brekker kryssrefranser/interne lenker)
        ActiveDocument.Bookmarks.ShowHidden = True
        Dim objBookmark As Bookmark
        For Each objBookmark In ActiveDocument.Bookmarks
          objBookmark.Delete
        Next
    End If
End If

' ======= STILOPPRYDDING =======
    
Application.Statusbar = "Starter stilopprydding..."
    
If ActiveDocument.Styles.Count > 1000 Then 'Sjekk om det er veldig mange stiler i dokumentet (i s fall gi advarsel og evt. kjr opprydding). Mange stiler gjr "stilopprydding"-funksjonen treg, og hvis dokumentet har makset ut antall stiler fr malen ble tilknyttet vil den ikke ha klart  importere alle stilene fra malen.

    'Spr om bruker vil fortsette opprydding eller avbryte makro. Obs: Makro vil feile hvis det er en tegnstil og avsnittsstil med samme navn (?!)
    Dim opprydding As VbMsgBoxResult
    opprydding = MsgBox(ActiveDocument.Styles.Count & " stiler i dokumentet, noe som gir treg stilopprydding." & vbNewLine & vbNewLine & "nsker du  fjerne alle ubrukte stiler fra dokumentet?" & vbNewLine & "Dette tar flere minutter (og kan i sjeldne tilfeller henge).", vbYesNo + vbExclamation + vbDefaultButton1, "Ekstrem mengde stiler funnet") '

    If opprydding = vbYes Then '--- Hvis OK, kjr opprydding av stiler
        '---Start oppryddingen---
        
        '(Fjerner Char-stiler, ubrukte stiler, og alle stil-alias, og til slutt importerer ferske stiler fra malen)
        
        'Fjerner alias for alle stiler (S f.eks. "Overskrift 1; Overskrift 1 tegn tegn" bare blir "Overskrift 1")
        Application.Statusbar = "Sletter alias for stiler..."
        Dim sty As Style
        For Each sty In ActiveDocument.Styles
            If sty.Type = wdStyleTypeParagraph Or sty.Type = wdStyleTypeCharacter Then
                sty.NameLocal = Split(sty.NameLocal, strListSep)(0)
                ActiveDocument.UndoClear    'Tm angre-historikk (ellers vil til slutt Word henge ved stor mengde stiler)
            End If
        Next sty
                        
    
        ' Loop through all Styles [for  slette "Char"/"Tegn"-stiler som ofte er synderen]
        Dim myStyle As Style
        Dim styleName As String

        Application.Statusbar = "Sletter stiler med Char/Tegn i navnet (dette kan ta tid)..."
        For Each myStyle In ActiveDocument.Styles
            styleName = myStyle.NameLocal
    
            ' Check if the style name ends with "Char"/"Tegn" followed by 1-2 numbers
            If styleName Like "*Char##" Or styleName Like "*Char#" Or styleName Like "*Tegn#" Or styleName Like "*Tegn##" Then
                myStyle.Delete              'Slett stilen
                ActiveDocument.UndoClear    'Tm angre-historikk (ellers vil til slutt Word henge ved stor mengde stiler)
            End If
    
        Next myStyle
        
        ' Loop through all Styles [for  slette alle ubrukte stiler for  ytterligere trimme ned antallet].
        Application.Statusbar = "Sletter ubrukte stiler (dette kan ta litt tid)..."
        For Each myStyle In ActiveDocument.Styles
            'Only execute if current style isn't a built-in style
            If myStyle.BuiltIn = False Then
                With ActiveDocument.Content.Find
                    .ClearFormatting
                    .Style = myStyle.NameLocal
                    .Execute FindText:="", Format:=True
                    If .found = False Then myStyle.Delete 'Slett stilen hvis den ikke ble funnet i teksten
                    ActiveDocument.UndoClear              'Tm angre-historikk (ellers vil til slutt Word henge ved stor mengde stiler)
                End With
            End If
        Next
                    
        ActiveDocument.UpdateStyles 'Importer ferske stiler fra dokumentmalen (ndvendig da noen er slettet, og hvis alle ikke var kommet inn pga. makset ut antall stiler)
        
        Application.Statusbar = "Stilopprydding fullfrt. Fortsetter med opprydding av manustekst..."

    End If

End If

'==== Stilopprydding ferdig ====


'Sett tabellstilen "StandardBoks" p tabeller med 1 celle
Dim tbl As Table
For Each tbl In ActiveDocument.Tables
    If tbl.Range.Information(wdWithInTable) = True Then
        If tbl.Rows.Count = 1 And tbl.Columns.Count = 1 Then
            tbl.Style = "StandardBoks"
        End If
    End If
Next tbl


' ====== Fotnotetekst ======
' Legger p stilen "Fotnotetekst" p alle fotnoter. Er en forutsetning for enkelte senere operasjoner (som korrigering av tegnstiler).
    Dim fotnote As footnote
    For Each fotnote In ActiveDocument.Footnotes
        fotnote.Range.Style = "Fotnotetekst"
    Next fotnote
    

' ======= HOVEDDEL =======
' Her kommer hoveddelen av makroen. Den kjrer to ganger (en gang for innhold, en gang for fotnoter).
' Delene som fikser ting unikt for fotnoter kan antagelig forbedres s koden blir ryddigere.

' Har du flere sk-og-erstatt-strenger du nsker  legge til som skal kjres p bde innhold og fotnoter,
' foreslr jeg  legge det i starten av denne For-loopen.

Application.Statusbar = "Kjrer sk-og-erstatt i teksten..."

For i = 1 To 2 'Loop n gang - 2. gangen den kjrer gjennom vil vre for fotnoter

    'Bytt  som er laget som et sammensatt tegn, med vanlig .
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "a" & ChrW(778)
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    With Selection.Find
        .Text = "" & ChrW(778)
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Erstatt unicode 8208 ("Hyphen") med vanlig '-' ("Hypen-Minus"). Forekommer av og til i enkelte referanser.
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^u8208"           '"Hypen" er unicode 8208
        .Replacement.Text = "-"    '"Hypen-minus" er det vanlige tegnet '-'
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Fjern spesialtegn som noen har brukt som ser ut som tankestrek (og som antagelig blir missing glyph alle andre steder)
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ChrW(61485)     'U+F02D : <private-use>  antagelig kopiert streken fra streklister
        .Replacement.Text = "" 'Endres til tankestrek
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Fjern "zero width space". Et usynlig tegn som av og til kommer med p tekst kopiert fra lovdata.no.
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^u8203" 'Zero width space er unicode 8203
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "[^12^14]" 'Erstatt inndelingsskift/sideskift/spalteskift
        .Replacement.Text = "^p" 'Med vanlig avsnitt (evt. doble avsnitt fjernes senere i makro)
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = " {2" & strListSep & "}" '2 eller flere mellomrom
        .Replacement.Text = " " 'reduser til ett
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^t{2" & strListSep & "}" '2 eller flere tabulatorer
        .Replacement.Text = "^t" 'reduser til en
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^t " 'Tabulator + mellomrom
        .Replacement.Text = "^t" 'reduser til kun tabulator
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = " ^t" 'Mellomrom + Tabulator
        .Replacement.Text = "^t" 'reduser til kun tabulator
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "([!,]) (^2)"       'Fotnotereferanse med mellomrom foran seg (med mindre mellomromet kommer etter et komma)
        .Replacement.Text = "\1\2"  'Fjern mellomrommet
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True      'Obs!
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^f"                'Finn fotnotereferanser
        .Replacement.Text = "^&"    'Behold teksten; men evt. tegnstil fjernes
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchKashida = False
        .MatchDiacritics = False
        .MatchAlefHamza = False
        .MatchControl = False
        .MatchWildcards = False      'Obs!
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "(^2)(^2)"          'To stk. tilsttende fotnotereferanser
        .Replacement.Text = "\1^s\2" 'sett hardt mellomrom mellom de (fotnotereferanser m ha ftt fjernet tegnstilen frst, ellers blir mellomrommet hevet!)
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True      'Obs!
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    Selection.Find.Execute Replace:=wdReplaceAll 'M kjres to ganger (for  f med der det er mer enn 2 tilsttende)

    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ".{3" & strListSep & "}" '3 eller flere punktum
        .Replacement.Text = "" 'endre til ellipse
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'Obs!
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "[""" & ChrW(8220) & "]..<" '2 punktum i startet av sitat
        .Replacement.Text = """" 'endre til ellipse
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "> ..""" 'mellomrom og 2 punktum i slutten av sitat
        .Replacement.Text = " """ 'endre til ellipse
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = " .. " '2 punktum med mellomrom rundt
        .Replacement.Text = "  " 'endre til ellipse
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = ".." 'endre to punktum
        .Replacement.Text = "." 'til ett punktum
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Fjern mellomrom eller tabulator i starten av avsnitt.
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^13[ ^t]" 'Avsnitt + (mellomrom eller Tab)
        .Replacement.Text = "^p" 'Avsnitt
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    
    '==== Denne delen av koden fjerner tomme avsnitt ====
    
    Application.Statusbar = "Fjerner tomme avsnitt..."
    Dim MyRange As Range, oTable As Table, oCell As cell 'Setter variabler som skal brukes snart
        
    ' Reduser 2 eller flere tomme avsnitt til ett
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^13{2" & strListSep & "}" '2 eller fler avsnittstegn
        .Replacement.Text = "^p" 'reduser til ett
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
        .Execute Replace:=wdReplaceAll
    End With
   
    ' Slett tomt avsnitt hvis det er frste avsnitt
    Set MyRange = ActiveDocument.Paragraphs(1).Range
    If MyRange.Text = vbCr Then MyRange.Delete
    
   ' Slett tomt avsnitt hvis det er siste avsnitt
   ' Set MyRange = ActiveDocument.Paragraphs.Last.Range
   ' If MyRange.Text = vbCr Then MyRange.Delete
    
    ' For hver tabell (skal vi g gjennom tabellcellene og fjern tomme avsnitt i start/slutt)
    For Each oTable In ActiveDocument.Tables
    
        Set oCell = oTable.Range.Cells(1)
        'For hver celle i tabellen
        For Counter = 1 To oTable.Range.Cells.Count
    
            If Len(oCell.Range.Text) > 2 And _
                    oCell.Range.Characters(1).Text = vbCr Then
                'hvis cellen ikke er tom, men starter med et tomt avsnitt, slett avsnittet
                'Merk at en tom celle inneholder to tegn; avsnittsmerket og tegn for celleslutt
                oCell.Range.Characters(1).Delete
            End If
    
            If Len(oCell.Range.Text) > 2 And _
                    Asc(Right$(oCell.Range.Text, 3)) = 13 Then
                'hvis cellen ikke er tom, men slutter med et tomt avsnitt, slett avsnittet
                Set MyRange = oCell.Range
                MyRange.MoveEnd Unit:=wdCharacter, Count:=-1
                MyRange.Characters.Last.Delete
            End If
    
            Set oCell = oCell.Next
        Next Counter
    Next oTable
    
    '==== Ferdig med  fjerne tomme avsnitt ====
    
    Application.Statusbar = "Kjrer sk og erstatt p teksten..."
    
    If i = 1 Then 'Kjr denne kun p body - ikke fotnoter (gir problemer der)
        'Fjern mellomrom eller tabulator i slutten av avsnitt.
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
            .Text = "[ ^t]^13" '(Mellomrom eller tabulator) + avsnitt
            .Replacement.Text = "^p" 'Avsnitt
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = True 'obs
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
    End If
    

    With Selection.Find
        .Text = " - " 'Bytt bindestrek med luft rundt
        .Replacement.Text = " ^= " 'til tankestrek med luft rundt
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    

'==== 11 skestrenger som fikser vanlige skrivefeil i Prop./NOU/St.Meld/Innst. ====

    Application.Statusbar = "Fjerner vanlige skrivefeil i Prop./NOU/St.Meld/Innst..."

    Options.DefaultHighlightColorIndex = wdTurquoise 'Setter en uthevings-farge s utheving/highlighting fungerer
    
    'Vi starter med  utheve sitater. Dette s vi kan utelate de nr vi retter skrivefeil.
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("blokksit") 'Finn alle blokksitater
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Highlight = True 'Uthev bokksitatene
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'Obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll


    'Finn og fiks "Meld. St." med feil mellomrom/punktum og stor/liten forbokstav
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Kun sk p tekst som ikke er uthevet (sitater er uthevet, s de vil ikke pvirkes)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Mm]eld[ .]{1" & strListSep & "2}[Ss]t[. ]{1" & strListSep & "2}([0-9])"
        .Replacement.Text = "Meld. St. \1"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'Obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Finn og fiks "St.meld. nr. #" med feil mellomrom/punktum og feil med stor/liten forbokstav
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Ss]t[ .]{1" & strListSep & "2}[Mm]eld[ .]{1" & strListSep & "2}[Nn]r. ([0-9]{1" & strListSep & "3})"
        .Replacement.Text = "St.meld. nr. \1"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'Obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Finn og fiks "Ot/St.prp. nr. #" med feil mellomrom/punktum og feil med stor/liten forbokstav i prp/nr
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<([OS]t)[ .]{1" & strListSep & "2}[Pp]rp[ .]{1" & strListSep & "2}[Nn]r. ([0-9]{1" & strListSep & "3})"
        .Replacement.Text = "\1.prp. nr. \2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'Obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Finn og fiks "Ot/St.prop. nr. #" med feil mellomrom/punktum og feil med stor/liten forbokstav i prp/nr (denne tar de hvor "prp" har blitt skrevet som "prop")
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<([OS]t)[ .]{1" & strListSep & "2}[Pp]rop[ .]{1" & strListSep & "2}[Nn]r. ([0-9]{1" & strListSep & "3})"
        .Replacement.Text = "\1.prp. nr. \2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'Obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Finn "Prop ### L/S/LS" uten punktum, og legg til punktum. Fiks ogs manglende stor forbokstav.
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Pp]rop[ .]{1" & strListSep & "2}([0-9]{1" & strListSep & "3} [LS]{1" & strListSep & "2} \([0-9]{4})"
        .Replacement.Text = "Prop. \1"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Finn to firesifrede rstall i parentes (fra-til) og fjern luft (og gi de tankestrek).
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Kun sk p tekst som ikke er uthevet (sitater er uthevet, s de vil ikke pvirkes)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "(\([12][0189][0-9]{2}) [-] ([12][0189][0-9]{2}\))"
        .Replacement.Text = "\1\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Finn to firesifrede rstall i parentes (fra-til) og gi de tankestrek.
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "(\([12][0189][0-9]{2})-([12][0189][0-9]{2}\))"
        .Replacement.Text = "\1\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Finn NOU og legg til manglende mellomrom etter kolon og fiks feil med store/sm forbokstaver
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Nn][Oo][Uu]( [12][09][0-9]{2}:)([0-9]{1" & strListSep & "3})"
        .Replacement.Text = "NOU\1 \2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Fjern luft i rstall for St.Meld. (etter korrigert av skrivemte for St.Meld. tidligere i makro)
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<(St.meld. nr. [0-9]{1" & strListSep & "3} \([0-9]{4}) [-] ([0-9]{2" & strListSep & "4}\))"
        .Replacement.Text = "\1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Fjern luft i rstall for Ot/St.prp. (etter korrigert skrivemte)
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "([OS]t.prp. nr. [0-9]{1" & strListSep & "3} \([0-9]{4}) [-] ([0-9]{2" & strListSep & "4}\))"
        .Replacement.Text = "\1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Bytt til tankestrek i rstall for St.Meld. (etter korrigert av skrivemte for St.Meld.)
    With Selection.Find
        .Text = "<(St.meld. nr. [0-9]{1" & strListSep & "3} \([0-9]{4})\-([0-9]{2" & strListSep & "4}\))"
        .Replacement.Text = "\1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Bytt til tankestrek i rstall for St.prp. og Ot.prp. (etter korrigert skrivemte for S/Ot.prp.)
    With Selection.Find
        .Text = "([OS]t.prp. nr. [0-9]{1" & strListSep & "3} \([0-9]{4})\-([0-9]{2" & strListSep & "4}\))"
        .Replacement.Text = "\1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    
    'Korriger skrivemte for Innst. (L, S, LS, SL)
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Ii]nnst[ .]{1" & strListSep & "2}([0-9]{1" & strListSep & "3} [LS]{1" & strListSep & "2} \([0-9]{4})([0-9]{4}\))"
        .Replacement.Text = "Innst. \1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Fjern den midlertidige uthevingen fra sitatene igjen
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("blokksit") 'For sitater
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Highlight = False 'Fjern utheving
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Kjr sk-og-erstatt for  sette inn hardt ordmellomrom mellom "Prop. XX" og "L/S/LS/SL "
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<(Prop. [0-9]{1" & strListSep & "3}) ([LS]{1" & strListSep & "2} )"
        .Replacement.Text = "\1^s\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
        
    'Kjr sk-og-erstatt for  sette inn hardt ordmellomrom mellom "Innst. XX" og "L/S/LS/SL "
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<(Innst. [0-9]{1" & strListSep & "3}) ([LS]{1" & strListSep & "2} )"
        .Replacement.Text = "\1^s\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
ActiveDocument.UndoClear 'Kjrer denne en gang for sikkerhets skyld (tmmer angre-historikken). Normalt ikke ndvendig, men skader ikke.
    
'==== Ferdig med  fikse skrivefeil i RDOK-navn ====
       
'------------------- Denne delen fikser anfrselstegn -------------------------
' Denne makroen benytter Word's innebyggde funksjon for "Smart Quotes"/"typografiske anfrselstegn" til  oppdatere anfrselstegn og apostrofer.

    Application.Statusbar = "Oppdaterer anfrselstegn..."

    ' Sl p innstillingen for "Smart Quotes"-autokorrektur
    Options.AutoFormatAsYouTypeReplaceQuotes = True

    ' Oppdater alle doble anfrselstegn:
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = """"             'Sk etter "
        .Replacement.Text = """" 'Erstatt med "
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Oppdater alle enkle anfrselstegn/apostrofer:
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "'"             'Sk etter '
        .Replacement.Text = "'" 'Erstatt med '
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Bytt fra doble engelske til doble norske anfrselstegn. (I tilfelle forrige erstatning ble feil pga. sprk, eller hvis engelske var lagt inn fra fr).
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Endre okina til  (det har forekommet at noen har brukt okina i stedet for vanlig enkelt anfrselstegn)!
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ChrW(699)
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Endre "Modifier letter apostrophe" til  (det har forekommet at noen har brukt dette i stedet for vanlig enkelt anfrselstegn)
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ChrW(700)
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    

'-------------------^ Anfrselstegn er n fikset ^-------------------------
    
    Application.Statusbar = "Kjrer mer sk og erstatt i teksten..."
    
    'Harde ordmellomrom fjernes. (Etterflgende sk-og-erstatt-strenger setter inn nye).
    With Selection.Find
        .Text = "^s"
        .Replacement.Text = " "
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = " ([0-9])" 'Paragraftegn og mellomrom som etterflges av tall
        .Replacement.Text = "^s\1" 'Endre til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) ([0-9]{3})" 'Et tall ettefulgt av mellomrom og s tre tall
        .Replacement.Text = "\1^s\2" 'Bruk hardt mellomrom mellom tallene (tusenskille)
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    Selection.Find.Execute Replace:=wdReplaceAll
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    With Selection.Find.Font
        .Superscript = True 'Obs!
        .Subscript = False
    End With
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles("skrift-hevet")
    With Selection.Find
        .Text = "[!^2]"             'Finn hevet tekst *som ikke er en fotnotereferanse*
        .Replacement.Text = "^&"    'Behold teksten; men stilen settes til "skrift-hevet"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchKashida = False
        .MatchDiacritics = False
        .MatchAlefHamza = False
        .MatchControl = False
        .MatchWildcards = True      'Obs!
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    With Selection.Find.Font
        .Superscript = False
        .Subscript = True 'Obs!
    End With
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles("skrift-senket")
    With Selection.Find
        .Text = ""                  'Finn senket tekst*
        .Replacement.Text = "^&"    'Behold teksten; men stilen settes til "skrift-senket"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchKashida = False
        .MatchDiacritics = False
        .MatchAlefHamza = False
        .MatchControl = False
        .MatchWildcards = True      'Obs!
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "([0-9]) mill." 'Tall etterfulgt av mill.
        .Replacement.Text = "\1^smill." 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) mrd." 'Tall etterfulgt av mrd.
        .Replacement.Text = "\1^smrd." 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) kroner" 'Tall etterfulgt av kroner
        .Replacement.Text = "\1^skroner" 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) pst." 'Tall etterfulgt av pst.
        .Replacement.Text = "\1^spst." 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) %" 'Tall etterfulgt av %
        .Replacement.Text = "\1^s%" 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
   
   
   '---Skestrenger for  fikse mange forekomster av feil bruk av kursiv og fet---
   '---Fikser ikke gjennomstrek/understrek/sperret---
   '---Forutsetter at fotnoter har stilen "Fotnotetekst"---
   '---Fjerner ikke halvfet/kursiv tegnstil fra titler som i utgangspunktet er halvfet/kursiv---
   
   Application.Statusbar = "Legger p tegnstiler for kursiv/halvfet..."
   
   '---Fiks de fleste forekomster av italic/bold:---
   
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("kursiv") 'Hvis avsnittet har tegnstilen Kursiv
    With Selection.Find.Font
        .Italic = False                                    'Men ikke vises som kursiv
    End With
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles( _
        "Standardskrift for avsnitt")                      'Fjern tegnstilen (kursiv)
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("halvfet") 'Hvis avsnittet har tegnstilen halvfet
    With Selection.Find.Font
        .Bold = False                                       'Men ikke vises som bold
    End With
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles( _
        "Standardskrift for avsnitt")                       'Fjern tegnstilen (halvfet)
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("l-endring") 'Hvis avsnittet har tegnstilen l-endring
    With Selection.Find.Font
        .Italic = False                                    'Men ikke vises som kursiv
    End With
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles( _
        "Standardskrift for avsnitt")                      'Fjern tegnstilen (l-endring)
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
   
        Dim KursivAllowed As String
        Dim RngFind As Range, RngTxt As Range, stilnr As Long
        'Alfabetisk liste med stiler som tillater kursiv tegnstil (det meste utenom titler og lover):
        KursivAllowed = "alfaliste,alfaliste 2,alfaliste 3,alfaliste 4,alfaliste 5,blokksit,friliste,friliste 2,friliste 3,friliste 4,friliste 5,hengende-innrykk,Kilde,Liste,Liste 2,Liste 3,Liste 4,Liste 5,Liste bombe,Liste bombe 2,Liste bombe 3,Liste bombe 4,Liste bombe 5,Listeavsnitt,Listeavsnitt 2,Listeavsnitt 3,Listeavsnitt 4,Listeavsnitt 5,Normal,Note,Nummerert liste,Nummerert liste 2,Nummerert liste 3,Nummerert liste 4,Nummerert liste 5,Opplisting,Opplisting 2,Opplisting 3,Opplisting 4,Opplisting 5,Petit,romertall liste,romertall liste 2,romertall liste 3,romertall liste 4,romertall liste 5,TabellHode-kolonne,TabellHode-rad"
                Set RngTxt = Selection.Range
        For stilnr = 0 To UBound(Split(KursivAllowed, ","))      'Loop gjennom stiler som tillater kursiv
          Set RngFind = RngTxt.Duplicate
          With RngFind.Find
            .ClearFormatting
            .Style = ActiveDocument.Styles(Split(KursivAllowed, ",")(stilnr)) 'Finn tekst med den aktuelle stilen
            .Replacement.ClearFormatting
            .Replacement.Style = ActiveDocument.Styles("kursiv") 'Skal f tegnstilen kursiv
            .Font.Italic = True                                  'Hvis teksten er kursiv
            .Text = ""
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
            .Execute Replace:=wdReplaceAll
          End With
        Next
        
        Dim BoldAllowed As String
        'Dim RngFind As Range, RngTxt As Range, stilnr As Long
        'Alfabetisk liste med stiler som tillater halvfet tegnstil (det meste utenom titler og lover):
        BoldAllowed = "alfaliste,alfaliste 2,alfaliste 3,alfaliste 4,alfaliste 5,blokksit,friliste,friliste 2,friliste 3,friliste 4,friliste 5,hengende-innrykk,Kilde,Liste,Liste 2,Liste 3,Liste 4,Liste 5,Liste bombe,Liste bombe 2,Liste bombe 3,Liste bombe 4,Liste bombe 5,Listeavsnitt,Listeavsnitt 2,Listeavsnitt 3,Listeavsnitt 4,Listeavsnitt 5,Normal,Note,Nummerert liste,Nummerert liste 2,Nummerert liste 3,Nummerert liste 4,Nummerert liste 5,Opplisting,Opplisting 2,Opplisting 3,Opplisting 4,Opplisting 5,Petit,romertall liste,romertall liste 2,romertall liste 3,romertall liste 4,romertall liste 5,TabellHode-kolonne,TabellHode-rad"
                Set RngTxt = Selection.Range
        For stilnr = 0 To UBound(Split(BoldAllowed, ","))       'Loop gjennom stiler som tillater halvfet
          Set RngFind = RngTxt.Duplicate
          With RngFind.Find
            .ClearFormatting
            .Style = ActiveDocument.Styles(Split(BoldAllowed, ",")(stilnr)) 'Finn tekst med den aktuelle stilen
            .Replacement.ClearFormatting
            .Replacement.Style = ActiveDocument.Styles("halvfet") 'Skal f tegnstilen halvfet
            .Font.Bold = True                                     'Hvis teksten er bold
            .Text = ""
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
            .Execute Replace:=wdReplaceAll
          End With
        Next
        
        Selection.Find.ClearFormatting
        Selection.Find.Style = ActiveDocument.Styles("Fotnotetekst") 'Hvis avsnittet har stilen Fotnotetekst
        Selection.Find.Font.Bold = True                              'Og er bold
        Selection.Find.Replacement.ClearFormatting
        Selection.Find.Replacement.Style = ActiveDocument.Styles("halvfet") 'Sett p tegnstilen "halvfet"
        With Selection.Find
            .Text = ""
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        Selection.Find.ClearFormatting
        Selection.Find.Style = ActiveDocument.Styles("Fotnotetekst") 'Hvis avsnittet har stilen Fotnotetekst
        Selection.Find.Font.Italic = True                            'Og er kursiv
        Selection.Find.Replacement.ClearFormatting
        Selection.Find.Replacement.Style = ActiveDocument.Styles("kursiv") 'Sett p tegnstilen "kursiv"
        With Selection.Find
            .Text = ""
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        Selection.Find.ClearFormatting
        Selection.Find.Style = ActiveDocument.Styles("l-ledd") 'Hvis avsnittet har stilen l-ledd
        Selection.Find.Font.Italic = True                            'Og er kursiv
        Selection.Find.Replacement.ClearFormatting
        Selection.Find.Replacement.Style = ActiveDocument.Styles("l-endring") 'Sett p tegnstilen "l-endring"
        With Selection.Find
            .Text = ""
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        Selection.Find.ClearFormatting
        Selection.Find.Style = ActiveDocument.Styles("l-punktum") 'Hvis avsnittet har stilen l-punktum
        Selection.Find.Font.Italic = True                            'Og er kursiv
        Selection.Find.Replacement.ClearFormatting
        Selection.Find.Replacement.Style = ActiveDocument.Styles("l-endring") 'Sett p tegnstilen "l-endring"
        With Selection.Find
            .Text = ""
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        Selection.Find.Replacement.Style = ActiveDocument.Styles( _
            "Fotnotereferanse")         'Legg stilen "Fotnotereferanse"
        With Selection.Find
            .Text = "^f"                'P alle fotnotereferanser (dette gjres fordi de kan ha blitt kursiv etter forrige skestrenger)
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
    
    '---ferdig med  fikse kursiv ---
       
    
    If ActiveDocument.Footnotes.Count <> 0 Then 'Hvis dokumentet har fotnoter:
      
        Application.Statusbar = "Rydder fotnoter..."
        
        
        'Denne biten kode fjerner mellomrommet i starten av fotnotetekst. Code by Paul Edstein.
        Dim FtNt As footnote
        For Each FtNt In ActiveDocument.Footnotes
          With FtNt.Range.Characters.First.Previous
            If .Text = " " Then .Text = vbNullString 'Bytt vbNullString til vbTab hvis du vil legge til tab i stedet
          End With
        Next
              
        'Marker fotnotene (s nr den straks looper blir de prosessert i stedet for innhold).
        ActiveDocument.Footnotes(1).Range.WholeStory
        ActiveDocument.Footnotes(1).Range.Select
        
        'Fjern parentes etter fotnotereferansene (kun i fotnoter, ikke i body)
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
          .Text = "(^2)\)"         'Fotnotereferanse+parentes
          .Replacement.Text = "\1" 'behold kun fotnotereferanse
          .Forward = True
          .Wrap = wdFindContinue
          .Format = False
          .MatchCase = False
          .MatchWholeWord = False
          .MatchAllWordForms = False
          .MatchSoundsLike = False
          .MatchWildcards = True
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
      
      
' DISSE LINJENE ER KOMMENTERT UT DA DEN KAN SKAPE EN UENDELIG LOOP HVIS DET EKSISTERER EN TOM FOTNOTE (men fungerer ellers bra). Noen som vet hvordan det kan gjres bedre?
'       'Fjern ekstra avsnitt i fotnotene
'        NoteCount = ActiveDocument.Footnotes.Count
'
'        Selection.Find.ClearFormatting
'        Selection.Find.Replacement.ClearFormatting
'        With Selection.Find
'            .Text = "^p^p"
'            .Replacement.Text = ""
'            .Forward = True
'            .Wrap = wdFindContinue
'            .Format = False
'            .MatchCase = False
'            .MatchWholeWord = False
'            .MatchAllWordForms = False
'            .MatchSoundsLike = False
'            .MatchWildcards = False
'        End With
'        Selection.Find.Execute
'
'        On Error GoTo TrapTheError
'        While Selection.Find.Found
'
'        Selection.MoveLeft
'        'The following line may trigger an error!
'        Selection.Delete
'        Selection.Find.Execute
'
'        Wend
'        GoTo TheEnd
'
'TrapTheError:
'            ErrorCount = ErrorCount + 1
'            Selection.MoveRight
'            Selection.Delete
'            If ErrorCount < NoteCount Then Resume Next
'
'TheEnd:
    
    Else 'Hvis det ikke var fotnoter...
        i = 3 'Endre "i" s den ikke looper, da vi er ferdige.
    End If

Next 'Macro looper (n gang) hvis det er fotnoter.


'==== Sk etter safelinks.protection.outlook.com-lenker i teksten. Disse kan komme p lenker kopiert fra Outlook, og kan lekke personinformasjon. Bruker m manuelt endre til korrektr URL ====
    Dim objDoc As Document
    Dim objLink As hyperlink
    Dim strLinkAddress As String
    Dim invalidLinksFound As Boolean
    Dim commentText As String
    Dim rngStory As Range
    Dim footnote As footnote

    Set objDoc = ActiveDocument
    invalidLinksFound = False
    commentText = "'protection.outlook.com'-lenke (kan lekke personinformasjon) som m endres til korrekt URL. Flg lenken, og kopier korrekt URL fra landingssiden."

    With objDoc
        ' Loop through all story ranges in the document
        For Each rngStory In .StoryRanges
          If rngStory.StoryType = wdMainTextStory Or rngStory.StoryType = wdFootnotesStory Then
            Do
                ' Loop through all hyperlinks in the current story range
                For Each objLink In rngStory.Hyperlinks
                    strLinkAddress = objLink.Address

                    ' Check for specific unwanted URL
                    If InStr(strLinkAddress, "safelinks.protection.outlook.com") > 0 Then
                        ' Check if the hyperlink is in a footnote
                        If rngStory.StoryType = wdFootnotesStory Then
                            ' Find the corresponding footnote reference in the main text
                            For Each footnote In .Footnotes
                                If objLink.Range.InRange(footnote.Range) Then
                                    objLink.Range.HighlightColorIndex = wdTurquoise 'Uthev med Cyan
                                    .Comments.Add Range:=footnote.Reference, Text:="Fotnote inneholder 'protection.outlook.com'-lenke (kan lekke personinformasjon). Denne m endres til korrekt URL. Flg lenken, og kopier korrekt URL fra landingssiden."
                                    Exit For
                                End If
                            Next footnote
                        Else
                            .Comments.Add Range:=objLink.Range, Text:=commentText
                        End If
                        invalidLinksFound = True
                    End If

                    DoEvents
                Next objLink

                ' Move to the next story range (e.g., footnotes, headers, etc.)
                Set rngStory = rngStory.NextStoryRange
            Loop Until rngStory Is Nothing
          End If
        Next rngStory

        ' Show a message if any invalid links were found
        If invalidLinksFound Then
            ActiveWindow.View.ShowComments = True
            MsgBox "Lenker med problemer funnet, se kommentarer i dokumentet.", vbExclamation
        End If
    End With
'==== Ferdig med sjekk av lenker ====
   
'Setter sk/erstatt-innstillingene til  ske etter mulige forekomster som br endres til tankestrek. Dette ligger da klart hvis man vil kjre dette manuelt nr makro er ferdig.
Selection.Find.ClearFormatting
Selection.Find.Replacement.ClearFormatting
With Selection.Find
    .Text = "([0-9])-([0-9])"
    .Replacement.Text = "\1\2"
    .Wrap = wdFindContinue
    .Format = True
    .MatchCase = False
    .MatchWholeWord = False
    .MatchKashida = False
    .MatchDiacritics = False
    .MatchAlefHamza = False
    .MatchControl = False
    .MatchWildcards = True
    .MatchSoundsLike = False
    .MatchAllWordForms = False
End With

Application.Statusbar = "Ferdig!"
Application.DisplayStatusBar = False 'Gir Word tilbake kontrollen over statusbar (ikke sikkert det er ndvendig)
Application.ScreenUpdating = True 'N kan skjermbilde oppdateres igjen.
   
End Sub



Sub DSS_2_Opprydding_DOCX_fra_InDesign()

'
' Denne makroen fjerner all lokal formattering i innholdstekst og fotnoter. Se over autonummerering manuelt!
'
' Makro opprettet 18.12.2020 av Jonas M. Rogne, Departementenes sikkerhets- og serviceorganisasjon.
' Denne versjonen ble sist oppdatert 27.11.2023
'
Application.ScreenUpdating = False 'Ikke oppdater skjermbilde mens makro kjrer.

If (ActiveDocument.CompatibilityMode = 11) Then  'CompatiblityMode er "11" p rtf-filer fra FM/ID, og minst 15 p dokumenter uten komaptibilitetsmodus.
    ActiveDocument.Convert                       'Fjern kompatibilitetsmodus. Gjr det bl.a. enklere  bytte Alt-tekst p bilder.
End If

    'Marker dokumentet, og fjern all direkte formattering (overrides)
    ActiveDocument.StoryRanges(wdMainTextStory).Select 'Make sure document text is selected (and not footnotes, footer, etc.)
    Selection.ClearCharacterDirectFormatting
    Selection.ClearParagraphDirectFormatting
    
    
    'Sett alle tabeller til sidebredde (s de ikke gr utenfor siden)
    Dim t As Table
    For Each t In ActiveDocument.Tables
        t.AutoFitBehavior wdAutoFitWindow
    Next t
    
        
    If ActiveDocument.Footnotes.Count <> 0 Then 'Hvis dokumentet har fotnoter:
        
    Dim FtNt As footnote
    For Each FtNt In ActiveDocument.Footnotes    'For hver fotnote
      With FtNt.Range.Characters.First.Previous  'Marker frste tegn etter fotnotenummeret
        If .Text = " " Then .Text = vbNullString 'Hvis det er et mellomrom, fjern det. (Bytt vbNullString til vbTab hvis du vil legge til tab i stedet)
      End With
      FtNt.Range.Select                          'Marker hele fotnoten
      Selection.ClearCharacterDirectFormatting   'Fjern lokal tegnformattering
      Selection.ClearParagraphDirectFormatting   'Fjern lokal avsnittsformattering
    Next
       
      
    End If
    
    ActiveDocument.StoryRanges(wdMainTextStory).Select 'Marker dokumentteksten (s man ikke str i f.eks. fotnoter)
    
    'Sett tabellstilen "StandardBoks" p tabeller med 1 celle
    Dim tbl As Table
    For Each tbl In ActiveDocument.Tables
        If tbl.Range.Information(wdWithInTable) = True Then
            If tbl.Rows.Count = 1 And tbl.Columns.Count = 1 Then
                tbl.Style = "StandardBoks"
            End If
        End If
    Next tbl
    
    ' Sett stilen "Normal" p alle avsnitt som kun inneholder et bilde
    Dim p As Paragraph
    Dim bFound As Boolean
    
    ' Loop through each paragraph in the document
    For Each p In ActiveDocument.Paragraphs
    
        ' Check if the paragraph only contains an image
        If p.Range.InlineShapes.Count = 1 And Len(p.Range.Text) = 2 Then
    
            ' Set the paragraph style to "Normal"
            p.Style = "Normal"
            bFound = True
    
        End If
    Next
    
    For i = 1 To 2 'Loop n gang - 2. gangen den kjrer gjennom vil vre for fotnoter

        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
            .Text = "^u173" 'Myke bindestreker fra InDesign (blir synlige i Word)
            .Replacement.Text = "" 'Slettes
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
            .Text = "^u0031" 'Myke bindestreker fra InDesign
            .Replacement.Text = "" 'Slettes
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
            .Text = " {2" & strListSep & "}" '2 eller flere mellomrom
            .Replacement.Text = " " 'reduser til ett
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = True 'obs
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        Selection.Find.Replacement.Style = ActiveDocument.Styles( _
            "Fotnotereferanse")         'Legg stilen "Fotnotereferanse"
        With Selection.Find
            .Text = "^f"                'P alle fotnotereferanser
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        If ActiveDocument.Footnotes.Count <> 0 Then 'Hvis dokumentet har fotnoter:
            'Marker fotnotene (s nr den straks looper blir de prosessert i stedet for innhold).
            ActiveDocument.Footnotes(1).Range.WholeStory
            ActiveDocument.Footnotes(1).Range.Select
        Else 'Hvis det ikke var fotnoter...
            i = 3 'Endre "i" s den ikke looper, da vi er ferdige.
        End If
        
    Next 'Macro looper (n gang) hvis det er fotnoter.
   
    'Tilbakestiller sk/erstatt-innstillingene (modifiser gjerne til det du normalt sker etter manuelt rett etter  ha kjrt makro).
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchKashida = False
        .MatchDiacritics = False
        .MatchAlefHamza = False
        .MatchControl = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With

    Application.ScreenUpdating = True    'N kan skjermbilde oppdateres igjen.

End Sub
Sub DSS_Bytt_norske_til_engelske_anfrselstegn()

'
' Makroen bytter norske  med engelske  i hele dokumentet.
' Kjr denne etter oppryddings-makro fr FrameMaker hvis du har engelsk manus.
'

Application.ScreenUpdating = False 'Ikke oppdater skjermbilde mens makro kjrer.

    ' Lagre dokumentets nvrende "Smart Quotes"-autokorrektur-innstilling
    Dim SETTING As Boolean: SETTING = Options.AutoFormatAsYouTypeReplaceQuotes

    ' Sl av innstillingen for "Smart Quotes"-autokorrektur (for sikkerhets skyld)
    Options.AutoFormatAsYouTypeReplaceQuotes = False

    ' Bytt fra doble norske til doble engelske anfrselstegn
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Tilbakestill dokumentets originale innstilling
    Options.AutoFormatAsYouTypeReplaceQuotes = SETTING

Application.ScreenUpdating = True 'N kan skjermbilde oppdateres igjen.

End Sub

Sub DSS_Endre_merket_tekst_til_rette_anfrselstegn()
' Makro opprettet 01.02.2021 av Jonas M. Rogne. Departementenes Sikkerhets- og serviceorganisasjon.
' Sist oppdatert 27.04.2021
' Denne makroen benytter Word's innebyggde funksjon for "Smart Quotes" til  oppdatere anfrselstegn og apostrofer.
' Den kjrer kun p teksten som er markert. ***Hvis ingen tekst er merket vil den kjre p hele den aktive tekstflyten.***

' Lagrer brukerinnstilling som variabel. Sett til false. Kjr sk-og-erstatt p anfrselstegn. Gjenopprett innstilling.

    ' Lagre brukers nvrende "Smart Quotes"-autokorrektur-innstilling
    Dim SETTING As Boolean: SETTING = Options.AutoFormatAsYouTypeReplaceQuotes
    
    ' Sl p innstillingen for "Smart Quotes"-autokorrektur
    Options.AutoFormatAsYouTypeReplaceQuotes = False
    
    ' Oppdater alle doble anfrselstegn:
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = """"             'Sk etter "
        .Replacement.Text = """" 'Erstatt med "
        .Forward = True
        .Wrap = wdFindStop
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Oppdater alle enkle anfrselstegn/apostrofer:
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "'"             'Sk etter '
        .Replacement.Text = "'" 'Erstatt med '
        .Forward = True
        .Wrap = wdFindStop
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Endre okina til ' (det har forekommet at noen har brukt okina i stedet for vanlig enkelt anfrselstegn)!
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ChrW(699)
        .Replacement.Text = "'"
        .Forward = True
        .Wrap = wdFindStop
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Endre "Modifier letter apostrophe" til ' (det har forekommet at noen har brukt dette i stedet for vanlig enkelt anfrselstegn)
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ChrW(700)
        .Replacement.Text = "'"
        .Forward = True
        .Wrap = wdFindStop
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Tilbakestill brukers originale innstilling
    Options.AutoFormatAsYouTypeReplaceQuotes = SETTING


End Sub


Sub DSS_Konverter_merket_figur_til_rasterbilde()
'
' Makro opprettet 04.2021 av Jonas M. Rogne. Departementenes Sikkerhets- og serviceorganisasjon.
'

' Konverter_merket_figur_til_rasterbilde Makro
' Konverter figur til bitmap (cut + paste as image)
' Opplsning (pikseldimensjoner) avhenger av de fysiske dimensjonene til bildet, s det er en god id  trekke det litt stort fr man kjrer makro (kan det inkluderes i makro?).
'
    Selection.Cut
    Selection.PasteSpecial Link:=False, DataType:=15, Placement:=wdInLine, _
        DisplayAsIcon:=False
End Sub

Sub DSS_Konverter_liste_til_tekst()

Selection.Range.ListFormat.ConvertNumbersToText

End Sub

